@@ -2,7 +2,7 @@ package Mojo::ACME;
 
 use Mojo::Base -base;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 $VERSION = eval $VERSION;
 
 use Mojo::Collection 'c';
@@ -248,7 +248,7 @@ Mojo::ACME - Mojo-based ACME-protocol client
 
 L<Let's Encrypt|https://letsencrypt.org> (also known as letsencrypt) is a service that provices free SSL certificates via an automated system.
 The service uses (and indeed defines) a protocol called ACME to securely communicate authentication, verification, and certificate issuance.
-If you aren't familiar with ACME or at least certificate issuance, you might want to see L<how it works|https://letsencrypt.org/howitworks/technology/> first.
+If you aren't familiar with ACME or at least certificate issuance, you might want to see L<how it works|https://letsencrypt.org/how-it-works> first.
 While many clients already exist, web framework plugins have the unique ability to handle the challenge response internally and therefore make for the easiest possible letsencrypt (or other ACME service) experience.
 
 =head1 DEVELOPMENT STATUS
@@ -329,9 +329,19 @@ L<http://github.com/jberger/Mojo-ACME>
 
 Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
 
+=head1 CONTRIBUTORS
+
+=over
+
+=item *
+
+Mario Domgoergen (mdom)
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Joel Berger
+Copyright (C) 2016 by Joel Berger and L</CONTRIBUTORS>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
